import {Button, Divider, TextArea} from "antd-mobile";
import {Fragment, useEffect, useMemo, useRef, useState} from "react";
import "./index.css"
import {useOutletContext, useSearchParams} from "react-router-dom";
import {addTaskLog, listTaskLog} from "../../api/detailLogTaskApi";
import dayjs from "dayjs";

export function DetailLogTask() {
    // 设置标题栏
    const {setTitle, setRightDesc} = useOutletContext();
    useEffect(() => {
        setTitle("日记/心得")
        setRightDesc(<Fragment/>);
    }, [])
    let [params] = useSearchParams();
    const textAreaRef = useRef(null);
    const [taskLogMap, setTaskLogMap] = useState([]);
    const [taskLogList, setTaskLogList] = useState([]);
    const [sendValue, setSendValue] = useState([]);

    const taskLogMapMemory = useMemo(() => {
        return taskLogList.reduce((map, taskLog) => {
            if (!map.has(dayjs(taskLog.createdDate).format("YYYY-MM-DD"))) {
                map.set(dayjs(taskLog.createdDate).format("YYYY-MM-DD"), []);
            }
            map.get(dayjs(taskLog.createdDate).format("YYYY-MM-DD"))?.push(taskLog);
            return map;
        }, new Map());
    }, [taskLogList])
    const handleSend = () => {
        addTaskLog({
            "description": sendValue,
            "taskId": params.get('id'),
        }).then(res => {
            // 加入当前集合中
            setTaskLogList([...taskLogList,res]);
        })
        setSendValue('')
        textAreaRef.current.focus();
    };
    useEffect(() => {
        textAreaRef.current.focus();
        // 获取之前的日志信息，根据日期分组排序，遍历map
        listTaskLog(`{
            "sortList":[{"direction":"DESC","property":"createdDate"}]
        }`).then(res => {
            console.log({res})
            if (res.content.length > 0) {
                setTaskLogList(res.content.reverse());
                // setTaskLogMap(res.content.reduce((map, taskLog) => {
                //     if (!map.has(dayjs(taskLog.createdDate).format("YYYY-MM-DD"))) {
                //         map.set(dayjs(taskLog.createdDate).format("YYYY-MM-DD"), []);
                //     }
                //     map.get(dayjs(taskLog.createdDate).format("YYYY-MM-DD"))?.push(taskLog);
                //     return map;
                // }, new Map()));
            }
        })
    }, [])
    return <Fragment>
        <div className="log-task-detail">
            <div className="log-detail">
                {
                    Array.from(taskLogMapMemory.keys()).map(key => {
                        return (<Fragment>
                            {dayjs().isSame(dayjs(key), "date") ?
                                <div key={key} style={{width: "100%", padding: "0 40px"}}>
                                    <Divider>今日</Divider>
                                </div> :
                                <div key={key} style={{width: "100%", padding: "0 20px"}}>
                                    <Divider>{key}</Divider>
                                </div>}
                            {taskLogMapMemory.get(key).map(taskLog => {
                                return <div key={taskLog.id} style={{ display: 'flex', width: "80%", padding: "2px 20px"}}>
                                    <span className="detail-line">{taskLog.description}</span>
                                </div>
                            })}</Fragment>)
                    })
                }
            </div>

            <div className="log-send">
                <TextArea
                    ref={(node) => {
                        textAreaRef.current = node;
                    }}
                    value={sendValue}
                    onChange={(val) => setSendValue(val)}
                    placeholder='输入日记心得，长按日记心得有惊喜'
                    rows={1}
                    autoSize={{minRows: 1, maxRows: 5}}
                    maxLength={100}
                />
                <Button
                    className="send-button"
                    onClick={handleSend}
                >发送
                </Button>
            </div>
        </div>

    </Fragment>

}